import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

export const constantRoutes = [
  {
    path: '/404',
    component: () => import('@/views/error-page/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/error-page/401'),
    hidden: true
  },
  {
    path: '/',
    redirect: '/taskboard',
  }
]

/**
 * asyncRoutes
 * the routes that need to be dynamically loaded based on user roles
 */
export const asyncRoutes = [

  {
    path: '/taskboard',
    component: () => import('@/views/taskboard/index'),
    name: 'TaskBoard',
    meta: { title: 'taskboard' }
    // name: 'TaskBoard',
    // meta: { title: 'Taskboard', icon: 'dashboard', affix: true }
  },
  {
    path: '/people',
    component: () => import('@/views/people/index'),
    name: 'People',
    meta: { title: 'People' }
    // name: 'TaskBoard',
    // meta: { title: 'Taskboard', icon: 'dashboard', affix: true }
  },
  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: [...constantRoutes,...asyncRoutes]
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
